@@ -7,6 +7,10 @@ checkArm <- function(object) {
   return(expectOneForAll(object, c("id", "subjects", "label")))
 }
 
+getEmptyBootstrap <- function() {
+  return(Bootstrap(data=data.frame(BS_ID=integer())))
+}
+
 #' 
 #' Arm class.
 #' 
@@ -30,7 +34,7 @@ setClass(
   contains="pmx_element",
   prototype=prototype(id=as.integer(NA), subjects=as.integer(1), label=as.character(NA),
                       protocol=new("protocol"), covariates=new("covariates"),
-                      bootstrap=Bootstrap(data=data.frame(BS_ID=integer())))
+                      bootstrap=getEmptyBootstrap())
 )
 
 #'
@@ -128,7 +132,25 @@ setMethod("add", signature = c("arm", "list"), definition = function(object, x)
 })
 
 setMethod("add", signature = c("arm", "treatment_entry"), definition = function(object, x) {
-  object@protocol@treatment <- object@protocol@treatment %>% add(x) 
+  existing <- object@protocol@treatment %>% find(x)
+  if (is.null(existing)) {
+    object@protocol@treatment <- object@protocol@treatment %>% add(x) 
+  } else {
+    oldAmount <- existing@amount
+    xAmount <- x@amount
+    existing@amount <- 0
+    x@amount <- 0
+    if (isTRUE(all.equal(existing, x))) {
+      # Combine old amount and new amount
+      existing@amount <- oldAmount + xAmount
+      # Replace old element
+      object@protocol@treatment <- object@protocol@treatment %>% replace(existing) 
+    } else {
+      where <- ifelse(object@id==0L, "dataset", object %>% getName())
+      stop(sprintf("Element '%s' already exists in %s and has different properties. Amounts cannot be added.",
+                   x %>% getName(), where))
+    }
+  }
   return(object)
 })
 
@@ -318,6 +340,16 @@ setMethod("show", signature=c("arm"), definition=function(object) {
   }
   show(object@protocol)
   cat("\n")
-  show(object@covariates)
+  hasBootstrap <- !isTRUE(all.equal(object@bootstrap, getEmptyBootstrap()))
+  hasCovariates <- length(object@covariates@list) > 0
+  if (hasBootstrap) {
+    if (hasCovariates) {
+      # Only show covariates if not empty
+      show(object@covariates)
+    }
+    show(object@bootstrap)
+  } else {
+    show(object@covariates) # Display 'No covariates' if empty list
+  }
 })
 
