@@ -296,7 +296,8 @@ simulateDelegate <- function(model, dataset, dest, events, scenarios, tablefun,
         if (replicates==1) {
           stop(cond)
         } else {
-          message(paste0("Error with replicate number ", replicate, ":"))
+          message(paste0("Error with replicate number ", replicate))
+          if (replicate==1) message(cond$message) # Only print error message for the first replicate
         }
         return(NULL)
       }
@@ -528,6 +529,7 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "rxode_engine", "ev
   keep <- outvars[outvars %in% c(summary@covariate_names, summary@iov_names, colnames(rxmod@omega))]
   solver <- settings@solver # Solver settings
   nocb <- settings@nocb@enable
+  tick_slice <- settings@progress@tick_slice
 
   results <- furrr::future_imap_dfr(.x=config$subdatasets, .f=function(subdataset, index) {
     inits <- getInitialConditions(subdataset, iteration=config$iteration, cmtNames=config$cmtNames)
@@ -546,8 +548,10 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "rxode_engine", "ev
     }
     
     # Tick progress
-    progress <- progress %>% updateSlice(index)
-    progress <- progress %>% tick()
+    if (tick_slice) {
+      progress <- progress %>% updateSlice(index)
+      progress <- progress %>% tick(tick_slice=tick_slice)
+    }
     
     # RxODE does not add the 'ID' column if only 1 subject
     if (!("id" %in% colnames(tmp))) {
@@ -564,6 +568,12 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "rxode_engine", "ev
     return(processDropOthers(tmp, outvars=outvars, dropOthers=config$dropOthers))
   }, .options=furrr::furrr_options(seed=TRUE, scheduling=getFurrrScheduling(settings@hardware@slice_parallel)))
   
+  # Tick progress
+  if (!tick_slice) {
+    progress <- progress %>% updateSlice(config$subdatasets %>% length())
+    progress <- progress %>% tick(tick_slice=tick_slice)
+  }
+  
   return(results %>% reorderColumns(dosing=dosing))
 })
 
@@ -585,12 +595,7 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "mrgsolve_engine",
   mrgmodHash <- digest::sha1(mrgmodCode)
   
   # Instantiate mrgsolve model
-  withCallingHandlers({
-    mod <- mrgsolve::mcode_cache(model=paste0("mod_", mrgmodHash), code=mrgmodCode, quiet=TRUE)
-  }, message = function(msg) {
-    if (msg$message %>% startsWith("(waiting)"))
-      invokeRestart("muffleMessage")
-  })
+  mod <- mrgsolve::mcode_cache(model=paste0("mod_", mrgmodHash), code=mrgmodCode, quiet=TRUE)
   
   # Retrieve THETA's
   thetas <- model@parameters %>% select("theta")
@@ -598,10 +603,11 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "mrgsolve_engine",
     purrr::set_names(thetas@list %>% purrr::map_chr(~.x %>% getNameInModel)) %>%
     purrr::map(~.x@value)
   
-  # Apply solver settings
+  # Apply simulation settings
   solver <- settings@solver
   mod <- mod %>% mrgsolve::update(atol=solver@atol, rtol=solver@rtol, hmax=solver@hmax, maxsteps=solver@maxsteps)
   nocb <- settings@nocb@enable
+  tick_slice <- settings@progress@tick_slice
 
   results <-  furrr::future_imap_dfr(.x=config$subdatasets, .f=function(subdataset, index) {
     inits <- getInitialConditions(subdataset, iteration=config$iteration, cmtNames=config$cmtNames)
@@ -621,10 +627,19 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "mrgsolve_engine",
     tmp <- mod %>% mrgsolve::data_set(data=subdataset) %>% mrgsolve::mrgsim(obsonly=!dosing, output="df", nocb=nocb) %>% tibble::as_tibble()
 
     # Tick progress
-    progress <- progress %>% updateSlice(index)
-    progress <- progress %>% tick()
-    
+    if (tick_slice) {
+      progress <- progress %>% updateSlice(index)
+      progress <- progress %>% tick(tick_slice=tick_slice)
+    }
+
     return(processDropOthers(tmp, outvars=outvars, dropOthers=config$dropOthers))
   }, .options=furrr::furrr_options(seed=TRUE, scheduling=getFurrrScheduling(settings@hardware@slice_parallel)))
+  
+  # Tick progress
+  if (!tick_slice) {
+    progress <- progress %>% updateSlice(config$subdatasets %>% length())
+    progress <- progress %>% tick(tick_slice=tick_slice)
+  }
+  
   return(results %>% reorderColumns(dosing=dosing))
 })
