@@ -10,9 +10,9 @@ test_that("Empty scenario", {
 })
 
 test_that("Scenario that overrides the default model", {
-  scenario <- Scenario("Scenario 1", model=model_suite$nonmem$advan1_trans1)
+  scenario <- Scenario("Scenario 1", model=model_suite$testing$nonmem$advan1_trans1)
   expect_equal(scenario@name, "Scenario 1")
-  expect_equal(scenario@model, model_suite$nonmem$advan1_trans1)
+  expect_equal(scenario@model, model_suite$testing$nonmem$advan1_trans1)
   expect_equal(scenario@dataset,  ~.x)
 })
 
@@ -26,7 +26,7 @@ test_that("Scenario that overrides the default dataset", {
 test_that("Incorrect scenario arguments are not accepted", {
   expect_error(Scenario(dataset=Dataset(1), model="ANYTHING"),
                regexp="model must be a CAMPSIS model, a function or a lambda formula")
-  expect_error(Scenario(dataset="ANYTHING", model=model_suite$nonmem$advan1_trans1),
+  expect_error(Scenario(dataset="ANYTHING", model=model_suite$testing$nonmem$advan1_trans1),
                regexp="dataset must be a CAMPSIS dataset, a function or a lambda formula")
 })
 
